ErrorCode

Enum ErrorCode 

#[repr(C)]
pub enum ErrorCode { Success = 0, NullPtr = 1, NotEnoughSpace = 2, InvalidBaseLen = 10, InvalidKeyLen = 11, CodeTooSmall = 12, CodeTooBig = 13, InvalidKey = 20, InvalidPeriod = 21, InvalidUTF8 = 30, }
Error codes used in the C interface.

C interface

The C interface uses an enum of type libreauth_oath_errno and the members has been renamed as follows:

Rust C
Success LIBREAUTH_OATH_SUCCESS
NullPtr LIBREAUTH_OATH_NULL_PTR
NotEnoughSpace LIBREAUTH_OATH_NOT_ENOUGH_SPACE
InvalidBaseLen LIBREAUTH_OATH_INVALID_BASE_LEN
InvalidKeyLen LIBREAUTH_OATH_INVALID_KEY_LEN
CodeTooSmall LIBREAUTH_OATH_CODE_TOO_SMALL
CodeTooBig LIBREAUTH_OATH_CODE_TOO_BIG
InvalidKey LIBREAUTH_OATH_INVALID_KEY
InvalidPeriod LIBREAUTH_OATH_INVALID_PERIOD
InvalidUTF8 LIBREAUTH_OATH_INVALID_UTF8

Variants



Success = 0



NullPtr = 1



NotEnoughSpace = 2



InvalidBaseLen = 10



InvalidKeyLen = 11



CodeTooSmall = 12



CodeTooBig = 13



InvalidKey = 20



InvalidPeriod = 21



InvalidUTF8 = 30